/* Tabela NOTAFISCAL */
/* Descrio: A trigger insere registros na tabela LOGOPERAESPE a partir de alteraes na tabela NOTAFISCAL */
/* Objetivo: Gerar um log que vai registrar as alteraes na tabela NOTAFISCAL
             utilizando a tabela Geral de Logs de Operaes especficas*/
/* Criao:
/* 23/05/2007 - Fabrcio Marcelo Silva */


CREATE OR REPLACE TRIGGER SDXLOG_LANCNF
AFTER INSERT OR UPDATE OR DELETE ON NOTAFISCAL FOR EACH ROW
DECLARE
   V_IDUTLOGLANCAMNF  VARCHAR2(1);
   V_IDTIPOOPER       VARCHAR2(1);  /* V_IDTIPOOPER - 'I' - Incluso, 'A' - Alterao, 'E' - Excluso */
   V_CLIENT_INFO      VARCHAR2(64);
   V_CDOPERADOR       VARCHAR2(12);
   V_CDFILIAL         VARCHAR2(4);
   V_DESC             VARCHAR2(2000);
   V_NMTIPOOPER       VARCHAR2(30);
BEGIN
   BEGIN
      SELECT IDUTLOGLANCAMNF
      INTO V_IDUTLOGLANCAMNF
      FROM PARAMGERAL
      WHERE CDPARGERAL = '0001';
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
         V_IDUTLOGLANCAMNF := 'N';
   END;

   IF V_IDUTLOGLANCAMNF = 'S' THEN

      V_IDTIPOOPER  := '';
      V_CLIENT_INFO := '';
      V_CDOPERADOR  := '';
      V_CDFILIAL    := '';
      V_DESC        := '';
      V_NMTIPOOPER  := '';

      BEGIN
         SELECT NMTIPOOPER
         INTO V_NMTIPOOPER
         FROM TIPOOPERAC
         WHERE
            IDENTRSAIDOP = :NEW.IDENTRSAIDOP  AND
            CDTIPOOPER   = :NEW.CDTIPOOPER;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            V_NMTIPOOPER := '';
      END;

      /* Retorna o codigo e o nome do operador */
      DBMS_APPLICATION_INFO.READ_CLIENT_INFO(V_CLIENT_INFO);
      V_CDOPERADOR := SUBSTR(V_CLIENT_INFO,1,12);

      IF DELETING THEN
         V_DESC := 'Filial:'                    || ' ' || :OLD.CDFILIAL    || ' ' ||
                   'Filial Recebimento:'        || ' ' || :OLD.CDFILIRECE  || ' ' ||
                   'Filial Emissao:'            || ' ' || :OLD.CDFILIEMIT  || ' ' ||
                   'N Lancamento:'             || ' ' || :OLD.NRLANCTONF  || ' ' ||
                   'Nota Fiscal:'               || ' ' || :OLD.NRNOTAFISC  || ' ' ||
                   'Fornecedor/Cliente/Filial:' || ' ' || :OLD.NRINSJURNF  || ' ' ||
                   'Valor Total:'               || ' ' || TO_CHAR(ROUND(:OLD.VRNOTAFISC, 2)) || ' ' ||
                   'Tipo de Transao:'         || ' ' || :OLD.CDTIPOOPER  || '-' || V_NMTIPOOPER;

         V_IDTIPOOPER := 'E';

         V_CDFILIAL   := :OLD.CDFILIAL;
      ELSE
         IF UPDATING THEN
            IF (NVL(:OLD.CDFILIAL,'')    <> NVL(:NEW.CDFILIAL,''))   OR
               (NVL(:OLD.CDFILIRECE,'')  <> NVL(:NEW.CDFILIRECE,'')) OR
               (NVL(:OLD.CDFILIEMIT,'')  <> NVL(:NEW.CDFILIEMIT,'')) OR
               (NVL(:OLD.NRLANCTONF,'')  <> NVL(:NEW.NRLANCTONF,'')) OR
               (NVL(:OLD.NRNOTAFISC,'')  <> NVL(:NEW.NRNOTAFISC,'')) OR
               (NVL(:OLD.NRINSJURNF,'')  <> NVL(:NEW.NRINSJURNF,'')) OR
               (NVL(:OLD.VRNOTAFISC,0)    <> NVL(:NEW.VRNOTAFISC, 0))  OR
               (NVL(:OLD.CDTIPOOPER,'')  <> NVL(:NEW.CDTIPOOPER,'')) THEN

               V_IDTIPOOPER := 'A';
            END IF;
         ELSE
            V_IDTIPOOPER := 'I';
         END IF;

         V_DESC := 'Filial:'                    || ' ' || :NEW.CDFILIAL    || ' ' ||
                   'Filial Recebimento:'        || ' ' || :NEW.CDFILIRECE  || ' ' ||
                   'Filial Emissao:'            || ' ' || :NEW.CDFILIEMIT  || ' ' ||
                   'N Lancamento:'             || ' ' || :NEW.NRLANCTONF  || ' ' ||
                   'Nota Fiscal:'               || ' ' || :NEW.NRNOTAFISC  || ' ' ||
                   'Fornecedor/Cliente/Filial:' || ' ' || :NEW.NRINSJURNF  || ' ' ||
                   'Valor Total:'               || ' ' || TO_CHAR(ROUND(:NEW.VRNOTAFISC, 2)) || ' ' ||
                   'Tipo de Transao:'         || ' ' || :NEW.CDTIPOOPER  || '-' || V_NMTIPOOPER;

         V_CDFILIAL := :NEW.CDFILIAL;
      END IF;

      IF NOT (V_DESC IS NULL)       AND
         NOT (V_IDTIPOOPER IS NULL) THEN

         V_DESC := SUBSTR(V_DESC, 1, 2000);

         INSERT INTO LOGOPERANF (NMOPERANF,     DTOPERANF,     IDOPERANF,
                                   CDOPERRESPOPNF, DSOPERANF, CDFILIRESPOPNF)
                     VALUES ('Lanc. NF',   SYSDATE,      V_IDTIPOOPER,
                             V_CDOPERADOR, V_DESC, V_CDFILIAL);
      END IF;
   END IF;
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('SDXLOG_LANCNF','5.05.021'); END;
/

